import React from 'react'
import Title from '../components/Title'
import Image from 'next/image'

const projectsData = [
    {
        type: "string",
        content: "Construction and development of the storage shed in Abu Flus Port – Basra – Iraq.",
        background: "bg-stone_opacity-500",
    },
    {
        type: "image",
        content: "/projects-1.png",
        background: "bg-stone_opacity-500",
    },
    {
        type: "string",
        content: "Construction of the weighbridge bridge in Abu Flus Port – Basra – Iraq.",
        background: "bg-orange-400",
    },
    {
        type: "string",
        content: "Design and construction of a container storage yard in Abu Flus Port – Basra – Iraq.",
        background: "bg-stone_opacity-500",
    },
    {
        type: "string",
        content: "Construction of a rain sewer network and cable ducts in Abu Flus Port – Basra – Iraq.",
        background: "bg-stone_opacity-500",
    },
    {
        type: "string",
        content: "Developing and rehabilitating the oil berth in the southern port of Umm-Qasr – Basra – Iraq.",
        background: "bg-orange-400",
    },
    {
        type: "image",
        content: "/projects-2.png",
        background: "bg-stone_opacity-500",
    },
    {
        type: "string",
        content: "Establishment of a shed for naval ships in Al- Maaqal- Basra – Iraq.",
        background: "bg-stone_opacity-500",
    },
    {
        type: "string",
        content: "Development of berth no. 1 in the southern port of Umm-Qasr – Basra – Iraq.",
        background: "bg-stone_opacity-500",
    },
    {
        type: "string",
        content: "Implementation of the entry and exit road project at the southern port of Umm-Qasr – Basra – Iraq.",
        background: "bg-stone_opacity-500",
    },
    {
        type: "image",
        content: "/projects-3.png",
        background: "bg-stone_opacity-500",
    },
    {
        type: "string",
        content: "Development of berth no. 4 in the southern port of Umm-Qasr – Basra – Iraq",
        background: "bg-stone_opacity-500",
    },
    {
        type: "string",
        content: "Establishing the main portal for the College of Engineering – University of Basra",
        background: "bg-stone_opacity-500",
    },
    {
        type: "string",
        content: "Establishment of a residential complex for the General Company for Ports of Iraq.",
        background: "bg-orange-400",
    },
    {
        type: "string",
        content: "Establishing a security fence gate in the large welcoming area in the southern port of Umm-Qasr – Basra – Iraq.",
        background: "bg-stone_opacity-500",
    },
    {
        type: "string",
        content: "Establishing a truck packing area at berth no. 3 in the southern port of Umm-Qasr – Basra – Iraq.",
        background: "bg-stone_opacity-500",
    },
    {
        type: "string",
        content: "Establishment of a residential of 200 houses – Wasit Governorate",
        background: "bg-stone_opacity-500",
    },
    {
        type: "string",
        content: "Various projects with the General Company for the Implementation of Transport Projects.",
        background: "bg-stone_opacity-500",
    },
]

const page = () => {
    return (
        <div className='pt-4 md:py-16 px-3 sm:px-12 2xl:px-[12%] flex flex-col gap-12 md:gap-20 lg:gap-24'>
            <div className="w-full flex flex-col gap-8 sm:gap-12 md:gap-14 lg:gap-20 items-center justify-center">
                <Title label="Discover Our Services" />
                <section className='w-full rounded-3xl bg-stone_opacity-300 grid gap-3 p-3 grid-cols-1 md:grid-cols-3 auto-rows-[12rem]'>
                    {
                        projectsData.map((item, i) => {
                            return (
                                <div key={i} className={`
                                    ${item.background} ${item.type === "string" ? "px-4 py-8" : ""} rounded-3xl flex items-center justify-center font-medium text-lg
                                    ${(i === 0 || i === 1 || i === 4 || i === 10 || i === 13 || i === 17) ? "row-span-2 md:row-[unset]" : ""}
                                    ${(i === 0 || i === 3 || i === 10 || i === 13 || i === 16) ? "md:row-span-2" : ""}
                                    ${(i === 1 || i === 14) ? "md:row-span-3" : ""}
                                    ${(i === 5) ? "md:col-span-3" : ""}
                                    ${(i === 9) ? "md:col-span-2" : ""}
                                `}

                                >
                                    {
                                        item.type === "string" ?
                                            <p className=''>
                                                {item.content}
                                            </p>
                                            :
                                            <Image
                                                width={1024}
                                                height={1024}
                                                alt={item.content}
                                                src={item.content}
                                                className='object-cover	w-full h-full rounded-3xl'
                                            />
                                    }
                                </div>
                            )

                        })
                    }
                </section>
            </div>
        </div>
    )
}

export default page

